@@ -1,10 +1,18 @@
 import pytest
-from dvc.testing.test_api import TestAPI  # noqa, pylint: disable=unused-import
-from dvc.testing.test_remote import (  # noqa, pylint: disable=unused-import
+from dvc.testing.api_tests import (  # noqa, pylint: disable=unused-import
+    TestAPI,
+)
+from dvc.testing.remote_tests import (  # noqa, pylint: disable=unused-import
     TestRemote,
 )
-from dvc.testing.test_workspace import TestAdd as _TestAdd
-from dvc.testing.test_workspace import TestImport as _TestImport
+from dvc.testing.workspace_tests import TestAdd as _TestAdd
+from dvc.testing.workspace_tests import TestImport as _TestImport
+from dvc.testing.workspace_tests import TestLsUrl as _TestLsUrl
+
+
+@pytest.fixture
+def cloud(make_cloud):
+    yield make_cloud(typ="s3")
 
 
 @pytest.fixture
@@ -43,3 +51,7 @@ class TestAdd(_TestAdd):
     @pytest.fixture
     def dir_hash_value(self):
         return "ec602a6ba97b2dd07bd6d2cd89674a60.dir"
+
+
+class TestLsUrl(_TestLsUrl):
+    pass
